keywords

# XMLRésuméLibrary: User Guide

keyword | Element Reference | label

## Name

keywords — Container for a list of keywords

## Synopsis

### Content Model

    (keyword+)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `keywords` element contains one or more keywords. These keywords are included in the HTML presentation as `<meta name="keywords" content="...">` tags.

### Parents

`keywords` may be contained in these elements: `resume`

## Examples

For examples, see `keyword`.

keyword | Element Reference | label